@@ -1,6 +1,8 @@
 import threading
 import time
-import paho.mqtt.client as mqtt
+import paho.mqtt.client as mqttc
+import paho.mqtt as mqtt
+from paho.mqtt.client import CallbackAPIVersion
 import json
 from typing import Optional  # Any, Union
 
@@ -14,6 +16,11 @@ DEFAULT_MQTT_HOST = "127.0.0.1"
 DEFAULT_MQTT_PORT = 1883
 
 
+mqtt_v = mqtt.__version__
+if mqtt_v[0] < '2':
+    logger.info(f"mqtt version is {mqtt_v} ")
+
+
 class MqttWrapper(threading.Thread):
     def __init__(self,
                  host: Optional[str] = DEFAULT_MQTT_HOST,
@@ -34,7 +41,12 @@ class MqttWrapper(threading.Thread):
         self.host = host
         self.port = port
         self.verbose = verbose
-        self.client = mqtt.Client()
+
+        # TODO: DeprecationWarning: Callback API version 1 is deprecated, update to latest version
+        if mqtt_v[0] < '2':
+            self.client = mqttc.Client()
+        else:
+            self.client = mqttc.Client(callback_api_version=CallbackAPIVersion.VERSION1)
 
         # Set username and password if provided
         self._username = username
