@@ -6,11 +6,9 @@ import time
 import requests
 from typing import Optional, Union
 
-
 from viso_sdk.constants import Module, NODE_ID, NODE_TYPE
 from viso_sdk.logging import get_logger
 
-
 logger = get_logger(name="FLOW")
 
 
@@ -155,7 +153,8 @@ class FlowAPIWrapper:
 
         for prev in prevs:
             prev_n, prev_port_id = prev['node'], prev['port']
-            if prev_n["type"] == Module.VideoFeed.type:
+            if prev_n["type"] in [Module.VideoFeed.type, Module.VFVideoFile.type, Module.VFUsbCamera.type,
+                                  Module.VFIpCamera.type]:
                 return prev_n, prev_port_id
             if len(self.seek_prev_nodes(prev_n)) == 0:
                 continue
