@@ -66,6 +66,17 @@ def get_adjusted_font(bbox_size):
     return font
 
 
+def get_adjusted_font_with_bbox(bbox_size, str_len):
+    box_width, box_height = bbox_size
+
+    font_size_by_height = max(int(box_height * 0.8), 10)
+    font_size_by_width = max(int(box_width / str_len * 2), 10)
+    font_size = min(font_size_by_width, font_size_by_height)
+    font = init_font(font_size=font_size)
+
+    return font
+
+
 def init_font(font_name=None, font_size=DEFAULT_FONT_SIZE):
     fonts = get_supported_fonts(FONTS_DIR)
     if font_name is not None and os.path.isabs(font_name) and os.path.exists(font_name):
@@ -95,7 +106,8 @@ def put_text(
         bg_thickness=-1,
         bg_color=DEFAULT_ROI_COLOR,
         show_shadow=False,
-        shadow_color=DEFAULT_SHADOW_COLOR
+        shadow_color=DEFAULT_SHADOW_COLOR,
+        spacing=4
 ):
     """
 
@@ -118,20 +130,22 @@ def put_text(
             True / False
         shadow_color:
             RGBA color
-
+        spacing: line space
     Returns:
 
     """
     text_width, text_height = get_text_size(draw=draw, text=text, font=font, xy=pos[:2])
     num_lines = text.count("\n") + 1
 
-    space = max(int(text_height // num_lines // 8), 1)
+    if not spacing:
+        spacing = max(int(text_height // num_lines // 8), 1)
+
     if large_padding:
-        padding_left = space * 8
-        padding_top = space * 4
+        padding_left = spacing * 8
+        padding_top = spacing * 4
     else:
-        padding_left = space
-        padding_top = space
+        padding_left = spacing
+        padding_top = spacing
 
     if len(pos) == 4:  # bbox
         x, y, w, h = pos[:4]
@@ -170,12 +184,14 @@ def put_text(
         draw.multiline_text(
             (x_text + 1, y_text + 1),
             font=font, text=text, fill=shadow_color,
+            spacing=spacing,
             align=align)
 
     # put text above rectangle
     draw.multiline_text(
         (x_text, y_text),
         font=font, text=text, fill=text_color,
+        spacing=spacing,
         align=align)
 
     return draw
