@@ -23,7 +23,7 @@ class VizPolygonDraw:
         self.show_roi = show_roi
         self.show_label = show_label
 
-        self.default_font = utils.init_font(font_size=label_size)
+        self.default_font = utils.init_font(font_size=int(label_size))
 
         if roi_color is None:
             roi_color = utils.DEFAULT_ROI_COLOR
